==> haskell-wai-websockets-3.0.1.2-570-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-Kgc0GG0lQN2Gn6Vsum63SV
key:                  wai-websockets-3.0.1.2-Kgc0GG0lQN2Gn6Vsum63SV
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  5f2dc730d797ab0d5a51c165d5b02726
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-Kgc0GG0lQN2Gn6Vsum63SV
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-6AEDVQFE46r4UgT1OZ8vwx
    http-types-0.12.4-GF9q12zDyJCA1fCuHO5qN
    network-3.1.4.0-1ps2oXOoyxa7GsNgS88GCq transformers-0.5.6.2
    wai-3.2.4-3Rb2R2bry06JIe4wFfvRMb
    websockets-0.12.7.3-J3XUG2WBtDxL93ixiCE6aq

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-571-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-1pZdXXL3EKI2dLBFdpoOiG
key:                  wai-websockets-3.0.1.2-1pZdXXL3EKI2dLBFdpoOiG
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  51fddcafa8d0016e66fada091f7b2863
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-1pZdXXL3EKI2dLBFdpoOiG
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2YJdsrn6pUkJFkSDuYKbj5
    http-types-0.12.4-36n5pJIqV0vLBUyZ9LbmPR
    network-3.1.4.0-7Sk2RzgIXBW6VjX8wm0Jln transformers-0.5.6.2
    wai-3.2.4-IaIgYS6oHRf4vNU7eyANj2
    websockets-0.12.7.3-59s0i3I4SJiDMsz5giXGdi

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
